==> pywasm-1.1.1.tar.gz: pywasm-1.1.1/pywasm/opcode.py <==
import typing

unreachable = 0x00
nop = 0x01
block = 0x02
loop = 0x03
if_then = 0x04
else_fi = 0x05
end = 0x0b
br = 0x0c
br_if = 0x0d
br_table = 0x0e
return_call = 0x0f
call = 0x10
call_indirect = 0x11
drop = 0x1a
select = 0x1b
local_get = 0x20
local_set = 0x21
local_tee = 0x22
global_get = 0x23
global_set = 0x24
i32_load = 0x28
i64_load = 0x29
f32_load = 0x2a
f64_load = 0x2b
i32_load8_s = 0x2c
i32_load8_u = 0x2d
i32_load16_s = 0x2e
i32_load16_u = 0x2f
i64_load8_s = 0x30
i64_load8_u = 0x31
i64_load16_s = 0x32
i64_load16_u = 0x33
i64_load32_s = 0x34
i64_load32_u = 0x35
i32_store = 0x36
i64_store = 0x37
f32_store = 0x38
f64_store = 0x39
i32_store8 = 0x3a
i32_store16 = 0x3b
i64_store8 = 0x3c
i64_store16 = 0x3d
i64_store32 = 0x3e
memory_size = 0x3f
memory_grow = 0x40
i32_const = 0x41
i64_const = 0x42
f32_const = 0x43
f64_const = 0x44
i32_eqz = 0x45
i32_eq = 0x46
i32_ne = 0x47
i32_lt_s = 0x48
i32_lt_u = 0x49
i32_gt_s = 0x4a
i32_gt_u = 0x4b
i32_le_s = 0x4c
i32_le_u = 0x4d
i32_ge_s = 0x4e
i32_ge_u = 0x4f
i64_eqz = 0x50
i64_eq = 0x51
i64_ne = 0x52
i64_lt_s = 0x53
i64_lt_u = 0x54
i64_gt_s = 0x55
i64_gt_u = 0x56
i64_le_s = 0x57
i64_le_u = 0x58
i64_ge_s = 0x59
i64_ge_u = 0x5a
f32_eq = 0x5b
f32_ne = 0x5c
f32_lt = 0x5d
f32_gt = 0x5e
f32_le = 0x5f
f32_ge = 0x60
f64_eq = 0x61
f64_ne = 0x62
f64_lt = 0x63
f64_gt = 0x64
f64_le = 0x65
f64_ge = 0x66
i32_clz = 0x67
i32_ctz = 0x68
i32_popcnt = 0x69
i32_add = 0x6a
i32_sub = 0x6b
i32_mul = 0x6c
i32_div_s = 0x6d
i32_div_u = 0x6e
i32_rem_s = 0x6f
i32_rem_u = 0x70
i32_and = 0x71
i32_or = 0x72
i32_xor = 0x73
i32_shl = 0x74
i32_shr_s = 0x75
i32_shr_u = 0x76
i32_rotl = 0x77
i32_rotr = 0x78
i64_clz = 0x79
i64_ctz = 0x7a
i64_popcnt = 0x7b
i64_add = 0x7c
i64_sub = 0x7d
i64_mul = 0x7e
i64_div_s = 0x7f
i64_div_u = 0x80
i64_rem_s = 0x81
i64_rem_u = 0x82
i64_and = 0x83
i64_or = 0x84
i64_xor = 0x85
i64_shl = 0x86
i64_shr_s = 0x87
i64_shr_u = 0x88
i64_rotl = 0x89
i64_rotr = 0x8a
f32_abs = 0x8b
f32_neg = 0x8c
f32_ceil = 0x8d
f32_floor = 0x8e
f32_trunc = 0x8f
f32_nearest = 0x90
f32_sqrt = 0x91
f32_add = 0x92
f32_sub = 0x93
f32_mul = 0x94
f32_div = 0x95
f32_min = 0x96
f32_max = 0x97
f32_copysign = 0x98
f64_abs = 0x99
f64_neg = 0x9a
f64_ceil = 0x9b
f64_floor = 0x9c
f64_trunc = 0x9d
f64_nearest = 0x9e
f64_sqrt = 0x9f
f64_add = 0xa0
f64_sub = 0xa1
f64_mul = 0xa2
f64_div = 0xa3
f64_min = 0xa4
f64_max = 0xa5
f64_copysign = 0xa6
i32_wrap_i64 = 0xa7
i32_trunc_f32_s = 0xa8
i32_trunc_f32_u = 0xa9
i32_trunc_f64_s = 0xaa
i32_trunc_f64_u = 0xab
i64_extend_i32_s = 0xac
i64_extend_i32_u = 0xad
i64_trunc_f32_s = 0xae
i64_trunc_f32_u = 0xaf
i64_trunc_f64_s = 0xb0
i64_trunc_f64_u = 0xb1
f32_convert_i32_s = 0xb2
f32_convert_i32_u = 0xb3
f32_convert_i64_s = 0xb4
f32_convert_i64_u = 0xb5
f32_demote_f64 = 0xb6
f64_convert_i32_s = 0xb7
f64_convert_i32_u = 0xb8
f64_convert_i64_s = 0xb9
f64_convert_i64_u = 0xba
f64_promote_f32 = 0xbb
i32_reinterpret_f32 = 0xbc
i64_reinterpret_f64 = 0xbd
f32_reinterpret_i32 = 0xbe
f64_reinterpret_i64 = 0xbf
i32_extend8_s = 0xc0
i32_extend16_s = 0xc1
i64_extend8_s = 0xc2
i64_extend16_s = 0xc3
i64_extend32_s = 0xc4
i32_trunc_sat_f32_s = 0xfc00
i32_trunc_sat_f32_u = 0xfc01
i32_trunc_sat_f64_s = 0xfc02
i32_trunc_sat_f64_u = 0xfc03
i64_trunc_sat_f32_s = 0xfc04
i64_trunc_sat_f32_u = 0xfc05
i64_trunc_sat_f64_s = 0xfc06
i64_trunc_sat_f64_u = 0xfc07

name: typing.Dict[int, str] = {}
name[unreachable] = 'unreachable'
name[nop] = 'nop'
name[block] = 'block'
name[loop] = 'loop'
name[if_then] = 'if'
name[else_fi] = 'else'
name[end] = 'end'
name[br] = 'br'
name[br_if] = 'br_if'
name[br_table] = 'br_table'
name[return_call] = 'return'
name[call] = 'call'
name[call_indirect] = 'call_indirect'
name[drop] = 'drop'
name[select] = 'select'
name[local_get] = 'local.get'
name[local_set] = 'local.set'
name[local_tee] = 'local.tee'
name[global_get] = 'global.get'
name[global_set] = 'global.set'
name[i32_load] = 'i32.load'
name[i64_load] = 'i64.load'
name[f32_load] = 'f32.load'
name[f64_load] = 'f64.load'
name[i32_load8_s] = 'i32.load8_s'
name[i32_load8_u] = 'i32.load8_u'
name[i32_load16_s] = 'i32.load16_s'
name[i32_load16_u] = 'i32.load16_u'
name[i64_load8_s] = 'i64.load8_s'
name[i64_load8_u] = 'i64.load8_u'
name[i64_load16_s] = 'i64.load16_s'
name[i64_load16_u] = 'i64.load16_u'
name[i64_load32_s] = 'i64.load32_s'
name[i64_load32_u] = 'i64.load32_u'
name[i32_store] = 'i32.store'
name[i64_store] = 'i64.store'
name[f32_store] = 'f32.store'
name[f64_store] = 'f64.store'
name[i32_store8] = 'i32.store8'
name[i32_store16] = 'i32.store16'
name[i64_store8] = 'i64.store8'
name[i64_store16] = 'i64.store16'
name[i64_store32] = 'i64.store32'
name[memory_size] = 'memory.size'
name[memory_grow] = 'memory.grow'
name[i32_const] = 'i32.const'
name[i64_const] = 'i64.const'
name[f32_const] = 'f32.const'
name[f64_const] = 'f64.const'
name[i32_eqz] = 'i32.eqz'
name[i32_eq] = 'i32.eq'
name[i32_ne] = 'i32.ne'
name[i32_lt_s] = 'i32.lt_s'
name[i32_lt_u] = 'i32.lt_u'
name[i32_gt_s] = 'i32.gt_s'
name[i32_gt_u] = 'i32.gt_u'
name[i32_le_s] = 'i32.le_s'
name[i32_le_u] = 'i32.le_u'
name[i32_ge_s] = 'i32.ge_s'
name[i32_ge_u] = 'i32.ge_u'
name[i64_eqz] = 'i64.eqz'
name[i64_eq] = 'i64.eq'
name[i64_ne] = 'i64.ne'
name[i64_lt_s] = 'i64.lt_s'
name[i64_lt_u] = 'i64.lt_u'
name[i64_gt_s] = 'i64.gt_s'
name[i64_gt_u] = 'i64.gt_u'
name[i64_le_s] = 'i64.le_s'
name[i64_le_u] = 'i64.le_u'
name[i64_ge_s] = 'i64.ge_s'
name[i64_ge_u] = 'i64.ge_u'
name[f32_eq] = 'f32.eq'
name[f32_ne] = 'f32.ne'
name[f32_lt] = 'f32.lt'
name[f32_gt] = 'f32.gt'
name[f32_le] = 'f32.le'
name[f32_ge] = 'f32.ge'
name[f64_eq] = 'f64.eq'
name[f64_ne] = 'f64.ne'
name[f64_lt] = 'f64.lt'
name[f64_gt] = 'f64.gt'
name[f64_le] = 'f64.le'
name[f64_ge] = 'f64.ge'
name[i32_clz] = 'i32.clz'
name[i32_ctz] = 'i32.ctz'
name[i32_popcnt] = 'i32.popcnt'
name[i32_add] = 'i32.add'
name[i32_sub] = 'i32.sub'
name[i32_mul] = 'i32.mul'
name[i32_div_s] = 'i32.div_s'
name[i32_div_u] = 'i32.div_u'
name[i32_rem_s] = 'i32.rem_s'
name[i32_rem_u] = 'i32.rem_u'
name[i32_and] = 'i32.and'
name[i32_or] = 'i32.or'
name[i32_xor] = 'i32.xor'
name[i32_shl] = 'i32.shl'
name[i32_shr_s] = 'i32.shr_s'
name[i32_shr_u] = 'i32.shr_u'
name[i32_rotl] = 'i32.rotl'
name[i32_rotr] = 'i32.rotr'
name[i64_clz] = 'i64.clz'
name[i64_ctz] = 'i64.ctz'
name[i64_popcnt] = 'i64.popcnt'
name[i64_add] = 'i64.add'
name[i64_sub] = 'i64.sub'
name[i64_mul] = 'i64.mul'
name[i64_div_s] = 'i64.div_s'
name[i64_div_u] = 'i64.div_u'
name[i64_rem_s] = 'i64.rem_s'
name[i64_rem_u] = 'i64.rem_u'
name[i64_and] = 'i64.and'
name[i64_or] = 'i64.or'
name[i64_xor] = 'i64.xor'
name[i64_shl] = 'i64.shl'
name[i64_shr_s] = 'i64.shr_s'
name[i64_shr_u] = 'i64.shr_u'
name[i64_rotl] = 'i64.rotl'
name[i64_rotr] = 'i64.rotr'
name[f32_abs] = 'f32.abs'
name[f32_neg] = 'f32.neg'
name[f32_ceil] = 'f32.ceil'
name[f32_floor] = 'f32.floor'
name[f32_trunc] = 'f32.trunc'
name[f32_nearest] = 'f32.nearest'
name[f32_sqrt] = 'f32.sqrt'
name[f32_add] = 'f32.add'
name[f32_sub] = 'f32.sub'
name[f32_mul] = 'f32.mul'
name[f32_div] = 'f32.div'
name[f32_min] = 'f32.min'
name[f32_max] = 'f32.max'
name[f32_copysign] = 'f32.copysign'
name[f64_abs] = 'f64.abs'
name[f64_neg] = 'f64.neg'
name[f64_ceil] = 'f64.ceil'
name[f64_floor] = 'f64.floor'
name[f64_trunc] = 'f64.trunc'
name[f64_nearest] = 'f64.nearest'
name[f64_sqrt] = 'f64.sqrt'
name[f64_add] = 'f64.add'
name[f64_sub] = 'f64.sub'
name[f64_mul] = 'f64.mul'
name[f64_div] = 'f64.div'
name[f64_min] = 'f64.min'
name[f64_max] = 'f64.max'
name[f64_copysign] = 'f64.copysign'
name[i32_wrap_i64] = 'i32.wrap_i64'
name[i32_trunc_f32_s] = 'i32.trunc_f32_s'
name[i32_trunc_f32_u] = 'i32.trunc_f32_u'
name[i32_trunc_f64_s] = 'i32.trunc_f64_s'
name[i32_trunc_f64_u] = 'i32.trunc_f64_u'
name[i64_extend_i32_s] = 'i64.extend_i32_s'
name[i64_extend_i32_u] = 'i64.extend_i32_u'
name[i64_trunc_f32_s] = 'i64.trunc_f32_s'
name[i64_trunc_f32_u] = 'i64.trunc_f32_u'
name[i64_trunc_f64_s] = 'i64.trunc_f64_s'
name[i64_trunc_f64_u] = 'i64.trunc_f64_u'
name[f32_convert_i32_s] = 'f32.convert_i32_s'
name[f32_convert_i32_u] = 'f32.convert_i32_u'
name[f32_convert_i64_s] = 'f32.convert_i64_s'
name[f32_convert_i64_u] = 'f32.convert_i64_u'
name[f32_demote_f64] = 'f32.demote_f64'
name[f64_convert_i32_s] = 'f64.convert_i32_s'
name[f64_convert_i32_u] = 'f64.convert_i32_u'
name[f64_convert_i64_s] = 'f64.convert_i64_s'
name[f64_convert_i64_u] = 'f64.convert_i64_u'
name[f64_promote_f32] = 'f64.promote_f32'
name[i32_reinterpret_f32] = 'i32.reinterpret_f32'
name[i64_reinterpret_f64] = 'i64.reinterpret_f64'
name[f32_reinterpret_i32] = 'f32.reinterpret_i32'
name[f64_reinterpret_i64] = 'f64.reinterpret_i64'
name[i32_extend8_s] = 'i32.extend8_s'
name[i32_extend16_s] = 'i32.extend16_s'
name[i64_extend8_s] = 'i64.extend8_s'
name[i64_extend16_s] = 'i64.extend16_s'
name[i64_extend32_s] = 'i64.extend32_s'
name[i32_trunc_sat_f32_s] = 'i32.trunc_sat_f32_s'
name[i32_trunc_sat_f32_u] = 'i32.trunc_sat_f32_u'
name[i32_trunc_sat_f64_s] = 'i32.trunc_sat_f64_s'
name[i32_trunc_sat_f64_u] = 'i32.trunc_sat_f64_u'
name[i64_trunc_sat_f32_s] = 'i64.trunc_sat_f32_s'
name[i64_trunc_sat_f32_u] = 'i64.trunc_sat_f32_u'
name[i64_trunc_sat_f64_s] = 'i64.trunc_sat_f64_s'
name[i64_trunc_sat_f64_u] = 'i64.trunc_sat_f64_u'

==> pywasm-2.1.5.tar.gz: pywasm-2.1.5/pywasm/opcode.py <==
import typing

unreachable = 0x00
nop = 0x01
block = 0x02
loop = 0x03
if_then = 0x04
else_fi = 0x05
end = 0x0b
br = 0x0c
br_if = 0x0d
br_table = 0x0e
return_call = 0x0f
call = 0x10
call_indirect = 0x11
drop = 0x1a
select = 0x1b
select_type = 0x1c
local_get = 0x20
local_set = 0x21
local_tee = 0x22
global_get = 0x23
global_set = 0x24
table_get = 0x25
table_set = 0x26
i32_load = 0x28
i64_load = 0x29
f32_load = 0x2a
f64_load = 0x2b
i32_load8_s = 0x2c
i32_load8_u = 0x2d
i32_load16_s = 0x2e
i32_load16_u = 0x2f
i64_load8_s = 0x30
i64_load8_u = 0x31
i64_load16_s = 0x32
i64_load16_u = 0x33
i64_load32_s = 0x34
i64_load32_u = 0x35
i32_store = 0x36
i64_store = 0x37
f32_store = 0x38
f64_store = 0x39
i32_store8 = 0x3a
i32_store16 = 0x3b
i64_store8 = 0x3c
i64_store16 = 0x3d
i64_store32 = 0x3e
memory_size = 0x3f
memory_grow = 0x40
i32_const = 0x41
i64_const = 0x42
f32_const = 0x43
f64_const = 0x44
i32_eqz = 0x45
i32_eq = 0x46
i32_ne = 0x47
i32_lt_s = 0x48
i32_lt_u = 0x49
i32_gt_s = 0x4a
i32_gt_u = 0x4b
i32_le_s = 0x4c
i32_le_u = 0x4d
i32_ge_s = 0x4e
i32_ge_u = 0x4f
i64_eqz = 0x50
i64_eq = 0x51
i64_ne = 0x52
i64_lt_s = 0x53
i64_lt_u = 0x54
i64_gt_s = 0x55
i64_gt_u = 0x56
i64_le_s = 0x57
i64_le_u = 0x58
i64_ge_s = 0x59
i64_ge_u = 0x5a
f32_eq = 0x5b
f32_ne = 0x5c
f32_lt = 0x5d
f32_gt = 0x5e
f32_le = 0x5f
f32_ge = 0x60
f64_eq = 0x61
f64_ne = 0x62
f64_lt = 0x63
f64_gt = 0x64
f64_le = 0x65
f64_ge = 0x66
i32_clz = 0x67
i32_ctz = 0x68
i32_popcnt = 0x69
i32_add = 0x6a
i32_sub = 0x6b
i32_mul = 0x6c
i32_div_s = 0x6d
i32_div_u = 0x6e
i32_rem_s = 0x6f
i32_rem_u = 0x70
i32_and = 0x71
i32_or = 0x72
i32_xor = 0x73
i32_shl = 0x74
i32_shr_s = 0x75
i32_shr_u = 0x76
i32_rotl = 0x77
i32_rotr = 0x78
i64_clz = 0x79
i64_ctz = 0x7a
i64_popcnt = 0x7b
i64_add = 0x7c
i64_sub = 0x7d
i64_mul = 0x7e
i64_div_s = 0x7f
i64_div_u = 0x80
i64_rem_s = 0x81
i64_rem_u = 0x82
i64_and = 0x83
i64_or = 0x84
i64_xor = 0x85
i64_shl = 0x86
i64_shr_s = 0x87
i64_shr_u = 0x88
i64_rotl = 0x89
i64_rotr = 0x8a
f32_abs = 0x8b
f32_neg = 0x8c
f32_ceil = 0x8d
f32_floor = 0x8e
f32_trunc = 0x8f
f32_nearest = 0x90
f32_sqrt = 0x91
f32_add = 0x92
f32_sub = 0x93
f32_mul = 0x94
f32_div = 0x95
f32_min = 0x96
f32_max = 0x97
f32_copysign = 0x98
f64_abs = 0x99
f64_neg = 0x9a
f64_ceil = 0x9b
f64_floor = 0x9c
f64_trunc = 0x9d
f64_nearest = 0x9e
f64_sqrt = 0x9f
f64_add = 0xa0
f64_sub = 0xa1
f64_mul = 0xa2
f64_div = 0xa3
f64_min = 0xa4
f64_max = 0xa5
f64_copysign = 0xa6
i32_wrap_i64 = 0xa7
i32_trunc_f32_s = 0xa8
i32_trunc_f32_u = 0xa9
i32_trunc_f64_s = 0xaa
i32_trunc_f64_u = 0xab
i64_extend_i32_s = 0xac
i64_extend_i32_u = 0xad
i64_trunc_f32_s = 0xae
i64_trunc_f32_u = 0xaf
i64_trunc_f64_s = 0xb0
i64_trunc_f64_u = 0xb1
f32_convert_i32_s = 0xb2
f32_convert_i32_u = 0xb3
f32_convert_i64_s = 0xb4
f32_convert_i64_u = 0xb5
f32_demote_f64 = 0xb6
f64_convert_i32_s = 0xb7
f64_convert_i32_u = 0xb8
f64_convert_i64_s = 0xb9
f64_convert_i64_u = 0xba
f64_promote_f32 = 0xbb
i32_reinterpret_f32 = 0xbc
i64_reinterpret_f64 = 0xbd
f32_reinterpret_i32 = 0xbe
f64_reinterpret_i64 = 0xbf
i32_extend8_s = 0xc0
i32_extend16_s = 0xc1
i64_extend8_s = 0xc2
i64_extend16_s = 0xc3
i64_extend32_s = 0xc4
ref_null = 0xd0
ref_is_null = 0xd1
ref_func = 0xd2
i32_trunc_sat_f32_s = 0xfc00
i32_trunc_sat_f32_u = 0xfc01
i32_trunc_sat_f64_s = 0xfc02
i32_trunc_sat_f64_u = 0xfc03
i64_trunc_sat_f32_s = 0xfc04
i64_trunc_sat_f32_u = 0xfc05
i64_trunc_sat_f64_s = 0xfc06
i64_trunc_sat_f64_u = 0xfc07
memory_init = 0xfc08
data_drop = 0xfc09
memory_copy = 0xfc0a
memory_fill = 0xfc0b
table_init = 0xfc0c
elem_drop = 0xfc0d
table_copy = 0xfc0e
table_grow = 0xfc0f
table_size = 0xfc10
table_fill = 0xfc11

name: typing.Dict[int, str] = {}
name[unreachable] = 'unreachable'
name[nop] = 'nop'
name[block] = 'block'
name[loop] = 'loop'
name[if_then] = 'if'
name[else_fi] = 'else'
name[end] = 'end'
name[br] = 'br'
name[br_if] = 'br_if'
name[br_table] = 'br_table'
name[return_call] = 'return'
name[call] = 'call'
name[call_indirect] = 'call_indirect'
name[drop] = 'drop'
name[select] = 'select'
name[select_type] = 'select'
name[local_get] = 'local.get'
name[local_set] = 'local.set'
name[local_tee] = 'local.tee'
name[global_get] = 'global.get'
name[global_set] = 'global.set'
name[table_get] = 'table.get'
name[table_set] = 'table.set'
name[i32_load] = 'i32.load'
name[i64_load] = 'i64.load'
name[f32_load] = 'f32.load'
name[f64_load] = 'f64.load'
name[i32_load8_s] = 'i32.load8_s'
name[i32_load8_u] = 'i32.load8_u'
name[i32_load16_s] = 'i32.load16_s'
name[i32_load16_u] = 'i32.load16_u'
name[i64_load8_s] = 'i64.load8_s'
name[i64_load8_u] = 'i64.load8_u'
name[i64_load16_s] = 'i64.load16_s'
name[i64_load16_u] = 'i64.load16_u'
name[i64_load32_s] = 'i64.load32_s'
name[i64_load32_u] = 'i64.load32_u'
name[i32_store] = 'i32.store'
name[i64_store] = 'i64.store'
name[f32_store] = 'f32.store'
name[f64_store] = 'f64.store'
name[i32_store8] = 'i32.store8'
name[i32_store16] = 'i32.store16'
name[i64_store8] = 'i64.store8'
name[i64_store16] = 'i64.store16'
name[i64_store32] = 'i64.store32'
name[memory_size] = 'memory.size'
name[memory_grow] = 'memory.grow'
name[i32_const] = 'i32.const'
name[i64_const] = 'i64.const'
name[f32_const] = 'f32.const'
name[f64_const] = 'f64.const'
name[i32_eqz] = 'i32.eqz'
name[i32_eq] = 'i32.eq'
name[i32_ne] = 'i32.ne'
name[i32_lt_s] = 'i32.lt_s'
name[i32_lt_u] = 'i32.lt_u'
name[i32_gt_s] = 'i32.gt_s'
name[i32_gt_u] = 'i32.gt_u'
name[i32_le_s] = 'i32.le_s'
name[i32_le_u] = 'i32.le_u'
name[i32_ge_s] = 'i32.ge_s'
name[i32_ge_u] = 'i32.ge_u'
name[i64_eqz] = 'i64.eqz'
name[i64_eq] = 'i64.eq'
name[i64_ne] = 'i64.ne'
name[i64_lt_s] = 'i64.lt_s'
name[i64_lt_u] = 'i64.lt_u'
name[i64_gt_s] = 'i64.gt_s'
name[i64_gt_u] = 'i64.gt_u'
name[i64_le_s] = 'i64.le_s'
name[i64_le_u] = 'i64.le_u'
name[i64_ge_s] = 'i64.ge_s'
name[i64_ge_u] = 'i64.ge_u'
name[f32_eq] = 'f32.eq'
name[f32_ne] = 'f32.ne'
name[f32_lt] = 'f32.lt'
name[f32_gt] = 'f32.gt'
name[f32_le] = 'f32.le'
name[f32_ge] = 'f32.ge'
name[f64_eq] = 'f64.eq'
name[f64_ne] = 'f64.ne'
name[f64_lt] = 'f64.lt'
name[f64_gt] = 'f64.gt'
name[f64_le] = 'f64.le'
name[f64_ge] = 'f64.ge'
name[i32_clz] = 'i32.clz'
name[i32_ctz] = 'i32.ctz'
name[i32_popcnt] = 'i32.popcnt'
name[i32_add] = 'i32.add'
name[i32_sub] = 'i32.sub'
name[i32_mul] = 'i32.mul'
name[i32_div_s] = 'i32.div_s'
name[i32_div_u] = 'i32.div_u'
name[i32_rem_s] = 'i32.rem_s'
name[i32_rem_u] = 'i32.rem_u'
name[i32_and] = 'i32.and'
name[i32_or] = 'i32.or'
name[i32_xor] = 'i32.xor'
name[i32_shl] = 'i32.shl'
name[i32_shr_s] = 'i32.shr_s'
name[i32_shr_u] = 'i32.shr_u'
name[i32_rotl] = 'i32.rotl'
name[i32_rotr] = 'i32.rotr'
name[i64_clz] = 'i64.clz'
name[i64_ctz] = 'i64.ctz'
name[i64_popcnt] = 'i64.popcnt'
name[i64_add] = 'i64.add'
name[i64_sub] = 'i64.sub'
name[i64_mul] = 'i64.mul'
name[i64_div_s] = 'i64.div_s'
name[i64_div_u] = 'i64.div_u'
name[i64_rem_s] = 'i64.rem_s'
name[i64_rem_u] = 'i64.rem_u'
name[i64_and] = 'i64.and'
name[i64_or] = 'i64.or'
name[i64_xor] = 'i64.xor'
name[i64_shl] = 'i64.shl'
name[i64_shr_s] = 'i64.shr_s'
name[i64_shr_u] = 'i64.shr_u'
name[i64_rotl] = 'i64.rotl'
name[i64_rotr] = 'i64.rotr'
name[f32_abs] = 'f32.abs'
name[f32_neg] = 'f32.neg'
name[f32_ceil] = 'f32.ceil'
name[f32_floor] = 'f32.floor'
name[f32_trunc] = 'f32.trunc'
name[f32_nearest] = 'f32.nearest'
name[f32_sqrt] = 'f32.sqrt'
name[f32_add] = 'f32.add'
name[f32_sub] = 'f32.sub'
name[f32_mul] = 'f32.mul'
name[f32_div] = 'f32.div'
name[f32_min] = 'f32.min'
name[f32_max] = 'f32.max'
name[f32_copysign] = 'f32.copysign'
name[f64_abs] = 'f64.abs'
name[f64_neg] = 'f64.neg'
name[f64_ceil] = 'f64.ceil'
name[f64_floor] = 'f64.floor'
name[f64_trunc] = 'f64.trunc'
name[f64_nearest] = 'f64.nearest'
name[f64_sqrt] = 'f64.sqrt'
name[f64_add] = 'f64.add'
name[f64_sub] = 'f64.sub'
name[f64_mul] = 'f64.mul'
name[f64_div] = 'f64.div'
name[f64_min] = 'f64.min'
name[f64_max] = 'f64.max'
name[f64_copysign] = 'f64.copysign'
name[i32_wrap_i64] = 'i32.wrap_i64'
name[i32_trunc_f32_s] = 'i32.trunc_f32_s'
name[i32_trunc_f32_u] = 'i32.trunc_f32_u'
name[i32_trunc_f64_s] = 'i32.trunc_f64_s'
name[i32_trunc_f64_u] = 'i32.trunc_f64_u'
name[i64_extend_i32_s] = 'i64.extend_i32_s'
name[i64_extend_i32_u] = 'i64.extend_i32_u'
name[i64_trunc_f32_s] = 'i64.trunc_f32_s'
name[i64_trunc_f32_u] = 'i64.trunc_f32_u'
name[i64_trunc_f64_s] = 'i64.trunc_f64_s'
name[i64_trunc_f64_u] = 'i64.trunc_f64_u'
name[f32_convert_i32_s] = 'f32.convert_i32_s'
name[f32_convert_i32_u] = 'f32.convert_i32_u'
name[f32_convert_i64_s] = 'f32.convert_i64_s'
name[f32_convert_i64_u] = 'f32.convert_i64_u'
name[f32_demote_f64] = 'f32.demote_f64'
name[f64_convert_i32_s] = 'f64.convert_i32_s'
name[f64_convert_i32_u] = 'f64.convert_i32_u'
name[f64_convert_i64_s] = 'f64.convert_i64_s'
name[f64_convert_i64_u] = 'f64.convert_i64_u'
name[f64_promote_f32] = 'f64.promote_f32'
name[i32_reinterpret_f32] = 'i32.reinterpret_f32'
name[i64_reinterpret_f64] = 'i64.reinterpret_f64'
name[f32_reinterpret_i32] = 'f32.reinterpret_i32'
name[f64_reinterpret_i64] = 'f64.reinterpret_i64'
name[i32_extend8_s] = 'i32.extend8_s'
name[i32_extend16_s] = 'i32.extend16_s'
name[i64_extend8_s] = 'i64.extend8_s'
name[i64_extend16_s] = 'i64.extend16_s'
name[i64_extend32_s] = 'i64.extend32_s'
name[ref_null] = 'ref.null'
name[ref_is_null] = 'ref.is_null'
name[ref_func] = 'ref.func'
name[i32_trunc_sat_f32_s] = 'i32.trunc_sat_f32_s'
name[i32_trunc_sat_f32_u] = 'i32.trunc_sat_f32_u'
name[i32_trunc_sat_f64_s] = 'i32.trunc_sat_f64_s'
name[i32_trunc_sat_f64_u] = 'i32.trunc_sat_f64_u'
name[i64_trunc_sat_f32_s] = 'i64.trunc_sat_f32_s'
name[i64_trunc_sat_f32_u] = 'i64.trunc_sat_f32_u'
name[i64_trunc_sat_f64_s] = 'i64.trunc_sat_f64_s'
name[i64_trunc_sat_f64_u] = 'i64.trunc_sat_f64_u'
name[memory_init] = 'memory.init'
name[data_drop] = 'data.drop'
name[memory_copy] = 'memory.copy'
name[memory_fill] = 'memory.fill'
name[table_init] = 'table.init'
name[elem_drop] = 'elem.drop'
name[table_copy] = 'table.copy'
name[table_grow] = 'table.grow'
name[table_size] = 'table.size'
name[table_fill] = 'table.fill'
